import { ModalService, Modal } from '@zeedhi/common';
import { Loader, Metadata } from '@zeedhi/core';
import { TekGrid, TekGridColumn } from '@zeedhi/teknisa-components-common';
import { DataSourceController } from '../DataSourceController';

export class DSLogController {
    private mainController: DataSourceController = Loader.getInstance("DataSourceController");

    private get datasourceData() {
        return this.mainController.datasourceData;
    }

    private detailModal!: Modal;
    public detailData: any = {};
    public async openLogModal({ row }: any) {
        this.detailModal?.destroy();
        this.detailModal = await ModalService.createFromJson('dataSource/Log/LogDetailModal', true);
        this.detailData = row || {};
        this.detailModal.show();
    }
    public closeLogModal() {
        this.detailModal.hide();
    }

    public logFormMounted({ component }: any) {
        const {VALUE_AFTER, VALUE_BEFORE} = this.detailData;

        component.value = this.detailData;
        if (VALUE_AFTER) component.value.VALUE_AFTER = typeof VALUE_AFTER === "string" ? VALUE_AFTER : JSON.stringify(this.detailData.VALUE_AFTER);
        if (VALUE_BEFORE) component.value.VALUE_BEFORE = typeof VALUE_BEFORE === "string" ? VALUE_BEFORE : JSON.stringify(this.detailData.VALUE_BEFORE);
    }

    public updateLog() {
        // Se grid não foi montado, não faz nada
        if (Metadata.getInstances("log-grid").length === 0 || !Metadata.getInstances("log-grid")[0]) {
            return;
        }
        const dataSourceId = this.datasourceData._id;
        const dataGrid: any = Metadata.getInstance<TekGrid>("log-grid");
        // dataGrid.datasource.setFilter({ collectionId: dataSourceId });
        dataGrid.datasource.dynamicFilter = {
            collectionId: [
              {
                operation: "EQUALS",
                relation: "AND",
                value: dataSourceId,
              }
            ]
          };
          dataGrid.datasource.get();
    }
}
